@@ -7,6 +7,10 @@ cat(" \n")
 cat("                   Robust marqLevAlg algorithm                   ", "\n")
 cat(" \n")
 cl <- x$cl
+minimize <- TRUE
+if(length(cl$minimize)){
+    if(cl$minimize==FALSE) minimize <- FALSE
+}
 dput(cl)
 cat(" \n")
 cat("Iteration process:", "\n")
@@ -26,20 +30,24 @@ if (x$ier == -1){
 }else{
 	cat("                    : Matrix inversion for RDM successful \n")
 }
-cat("                    : relative distance to maximum(RDM)=", round(x$rdm,digits), "\n")
+if(minimize==TRUE){
+    cat("                    : relative distance to minimum(RDM)=", round(x$rdm,digits), "\n")
+}else{
+    cat("                    : relative distance to maximum(RDM)=", round(x$rdm,digits), "\n")
+}
 if(x$istop!=4&x$istop!=5) {
 cat(" \n")
-cat("Final parameter values:", "\n")
-id <- 1:length(x$b)
-indice <- rep(id*(id+1)/2)
-se <-sqrt(x$v[indice])
-wald <- (x$b/se)**2
-z <- abs(qnorm((1 + .95)/2))
-binf <- x$b-1.96*se
-bsup <- x$b+1.96*se
+cat("Final parameter values:", "\n",format(round(x$b,3)),"\n")
+#id <- 1:length(x$b)
+#indice <- rep(id*(id+1)/2)
+#se <-sqrt(x$v[indice])
+#wald <- (x$b/se)**2
+#z <- abs(qnorm((1 + .95)/2))
+#binf <- x$b-1.96*se
+#bsup <- x$b+1.96*se
 
-tmp <- data.frame("coef"=format(round(x$b,3)),"SE coef"=format(round(se,3)),"Wald"=format(wald,4),"P-value"=round(1 - pchisq(wald, 1),5),"binf"=round(binf,3),"bsup"=round(bsup,3))
-print(tmp,row.names=F)
+#tmp <- data.frame("coef"=format(round(x$b,3)),"SE coef"=format(round(se,3)))#,"Wald"=format(wald,4),"P-value"=round(1 - pchisq(wald, 1),5),"binf"=round(binf,3),"bsup"=round(bsup,3))
+#print(tmp,row.names=F)
 cat(" \n")
 }
 }
